Check if an object is of class airdas_df, or coerce it if possible.
as_airdas_df(x)# S3 method for airdas_df
as_airdas_df(x)
# S3 method for data.frame
as_airdas_df(x)
An object of class airdas_df
An object to be coerced to class airdas_df
Currently only data frames can be coerced to an object
of class airdas_df.
If x does not have column names, classes, and contents
as specified in airdas_df,
then the function returns an error message detailing the first column that does not
meet the airdas_df requirements.
airdas_df-class