TRUE if writing of file was successful, and FALSE otherwise
Arguments
file
character; the name of the file where the PDF will be saved
file.type
character; indicates which data format PDF to extract.
Must be one of: "turtle", "caretta", "survey", or "phocoena" (case sensitive)
...
passed to file.copy;
might included named argument overwrite
Details
This function is a wrapper function for file.copy.
It saves a PDF document describing the specified aerial DAS data
format requirements by copying the PDF document to file
The PDF files can also be manually copied or downloaded from:
PHOCOENA
Can be copied from:
system.file("AirDAS_Format_PHOCOENA.pdf", package = "swfscAirDAS")