Learn R Programming

swfscAirDAS (version 0.3.1)

airdas_sight: Aerial DAS sightings

Description

Extract sighting information from aerial DAS data

Usage

airdas_sight(x, ...)

# S3 method for data.frame airdas_sight(x, ...)

# S3 method for airdas_df airdas_sight(x, angle.min = 12, ...)

Value

Data frame with 1) the columns from x, excluding the 'Data#' columns, and 2) columns with sighting information extracted from 'Data#' columns as described below. The data frame has one row for each sighting, or one row for each species of each sighting if it is a multi-species (mixed) sighting.

Added sighting information columns:

Sighting informationColumn nameNotes
Sighting numberSightNoObserver that made the sighting
ObsAngle of declinationAngle
Left is negativeSighting by standard observerObsStd
Logical; described in DetailsStandard sightingSightStd
Logical; described in DetailsMixed species sightingMixed
LogicalSpecies codeSpCode
All characters converted to lower caseGroup size of schoolGsTotal
Only different from GsSp for mixed species sightingsGroup size of speciesGsSp
Turtle length (feet if numeric)TurtleSizeNA for non-"t" events; may be character or numeric
Turtle travel direction (degrees)TurtleDirectionNA for non-"t" events
Turtle tail visible?TurtleTailNA for non-"t" events

The TurtleSize will be of class character is there is any CARETTA data in x, and of class numeric otherwise.

Arguments

x

airdas_df object; output from airdas_process, or a data frame that can be coerced to a airdas_df object

...

ignored

angle.min

numeric; the minimum (absolute value) angle for which to consider a sighting a standard sighting. Default is 12

Details

AirDAS events contain specific information in the 'Data#' columns, with the information depending on the event code and file type for that row. This function extracts relevant data for sighting events, and returns a data frame with dedicated columns for each piece of sighting information. It can handle multiple file types in x; for instance, x could be processed PHOCOENA and TURTLE data combined using rbind. See airdas_format_pdf for more information about the expected events and event formats, depending on the file type.

All species codes are converted to lower case using tolower.

Abbreviations used in column names include: Gs = group size, Sp = species, Mixed = mixed species (multi-species) sighting. In addition, note that multi-species group sizes are rounded to the nearest whole number using round(, 0)

A 'sighting by a standard observer' ('ObsStd') is a sighting made by ObsL, ObsB, or ObsR (not the data recorder or pilot). A 'standard sighting' ('SightStd') is a sighting that was made while on effort, by a standard observer, and with the absolute value of the angle of declination being greater than or equal to angle.min. Resights (Events 's') are not considered standard events, and thus both 'ObsStd' and 'SightStd' will be NA for 's' events.

Examples

Run this code
y <- system.file("airdas_sample.das", package = "swfscAirDAS")
y.proc <- airdas_process(y)

airdas_sight(y.proc)

Run the code above in your browser using DataLab