Check if an object is of class airdas_dfr, or coerce it if possible.
as_airdas_dfr(x)# S3 method for airdas_dfr
as_airdas_dfr(x)
# S3 method for data.frame
as_airdas_dfr(x)
An object of class `airdas_dfr`
An object to be coerced to class airdas_dfr
Currently only data frames can be coerced to an object of class airdas_dfr.
If x does not have column names and classes as specified in airdas_dfr,
then the function returns an error message detailing the first column that does not
meet the airdas_dfr requirements.
airdas_dfr-class